#############
Client Module
#############

.. currentmodule:: ovh.consumer_key

.. automodule:: ovh.consumer_key

.. autoclass:: ConsumerKeyRequest

Constructor
===========

__init__
--------

.. automethod:: ConsumerKeyRequest.__init__

Helpers
=======

Generate rules
--------------

.. automethod:: ConsumerKeyRequest.add_rule
.. automethod:: ConsumerKeyRequest.add_rules
.. automethod:: ConsumerKeyRequest.add_recursive_rules

Trigger request
---------------

.. automethod:: ConsumerKeyRequest.request

